@@ -35,9 +35,7 @@ def main(
         help="Choose a catalog topic.",
     ),
 ):
-    """![Downloading](https://github.com/JnyJny/springer_downloader/raw/master/demo/b.gif)
-
-    ![Longer Demo](https://github.com/JnyJny/springer_downloader/raw/master/demo/demo1_fast.gif)
+    """![Downloading](https://github.com/JnyJny/springer_downloader/raw/master/demo/download-catalog.gif)
     __Springer Textbook Bulk Download Tool__
     
     ## NOTICE
@@ -84,6 +82,14 @@ def main(
 
     **Note: The _Emergency Nursing_ topic is not available in English.**
 
+    ## Source and License
+
+    Full source is available on
+    [GitHub](https://github.com/JnyJny/springer_downloader) and it is
+    licensed under the
+    [Apache-2.0](https://www.apache.org/licenses/LICENSE-2.0)
+    license.
+
     ## Installation
 
     This utility can be installed using `pip`:
@@ -93,8 +99,6 @@ def main(
     Or from the latest source on GitHub:
 
     `$ python3 -m pip install git+https://github.com/JnyJny/springer_downloader`
-
-    The source is available on [GitHub](https://github.com/JnyJny/springer_downloader).
     """
 
     # EJO The callback function is called before any of the command functions
@@ -156,7 +160,9 @@ def set_default_catalog_subcommand(ctx: typer.Context,):
 def list_subcommand(
     ctx: typer.Context,
     component: Component,
-    match: str = typer.Option(None, "--match", "-m", help="String used for matching."),
+    name: str = typer.Option(
+        None, "--name", "-n", help="Name to match against title or pacakge."
+    ),
     long_format: bool = typer.Option(
         False,
         "--long-format",
@@ -203,15 +209,14 @@ def list_subcommand(
     """
 
     if component == Component.Books:
-
-        ctx.obj.list_textbooks(long_format, match)
+        ctx.obj.list_textbooks(long_format, name)
         return
 
     if component is Component.Package:
-        if match:
-            for name, package in ctx.obj.packages.items():
-                if match.casefold() in name.casefold():
-                    ctx.obj.list_package(name, package, long_format)
+        if name:
+            for pkgname, pkginfo in ctx.obj.packages.items():
+                if name.casefold() in pkgname.casefold():
+                    ctx.obj.list_package(pkgname, pkginfo, long_format)
             return
         else:
             component = Component.Packages
@@ -329,151 +334,13 @@ def _configure_logger(path: Path, logfile: str = None) -> None:
     )
 
 
-@cli.command(name="xxx-download")
+@cli.command("download")
 def download_subcommand(
-    ctx: typer.Context,
-    title: str = typer.Option(
-        None, "--book-title", "-t", help="Book title to match (partial title OK)"
-    ),
-    package: str = typer.Option(
-        None, "--package-name", "-p", help="Package name to match (partial name OK)."
-    ),
-    file_format: FileFormat = typer.Option(
-        FileFormat.pdf, "--format", "-f", show_default=True, show_choices=True
-    ),
-    dest_path: Path = typer.Option(
-        Path.cwd(),
-        "--dest-path",
-        "-d",
-        show_default=True,
-        help="Destination directory for downloaded files.",
-    ),
-    overwrite: bool = typer.Option(
-        False,
-        "--over-write",
-        "-W",
-        is_flag=True,
-        show_default=True,
-        help="Over write downloaded files.",
-    ),
-    all_catalogs: bool = typer.Option(
-        False, "--all", is_flag=True, help="Downloads books from all catalogs."
-    ),
-):
-    """Download textbooks from Springer.
-
-    This command will download all the textbooks found in the catalog
-    of free textbooks provided by Springer. The default file format 
-    is PDF and the files are saved by default to the current working
-    directory.
-
-    If a download is interrupted, you can re-start the download and it
-    will skip over files that have been previously downloaded and pick up
-    where it left off.
-
-    
-
-    If the --all option is specified, the --dest-path option specifies the
-    root directory where files will be stored. Each catalog will save 
-    it's textbooks to:
-    
-    `dest_path/language/topic/book_file_name.fmt`
-
-    Errors encountered during the download will be logged to a file named:
-
-    `dest_path/DOWNLOAD_REPORT.txt`
-    
-
-    __Examples__
-
-    Download all books in PDF format to the current directory:
-    
-    `$ springer download`
-    
-    Download all books in EPUB format to the current directory:
-
-    `$ springer download --format epub`
-
-    Download all books in PDF format to a directory `pdfs`:
-
-    `$ springer download --dest-path pdfs`
-
-    Download books in PDF format to `pdfs` with overwriting:
-
-    `$ springer download --dest-path pdfs --over-write`
-
-    Download all books in PDF from the German/All_Disciplines catalog:
-    
-    `$ springer --language de --topic all download --dest-path german/all/pdfs`
-
-    Download all books from all catelogs in epub format:
-
-    `$ springer download --all --format epub`
-
-    Download all books in the 'Computer Science' package in pdf format:
-
-    `$ springer download --package-name computer`
-    """
-
-    dest_path = dest_path.resolve()
-
-    _configure_logger(dest_path)
-
-    try:
-        if not all_catalogs:
-
-            dest_path.mkdir(mode=0o755, exist_ok=True, parents=True)
-
-            if title:
-                ctx.obj.download_title(title, dest_path, file_format, overwrite)
-                return
-
-            if package:
-                ctx.obj.download_package(package, dest_path, file_format, overwrite)
-                return
-
-            ctx.obj.download(dest_path, file_format, overwrite)
-            return
-
-        for catalog in Catalog.all_catalogs():
-            dest = dest_path / catalog.language.name / catalog.topic.value
-            dest.mkdir(mode=0o755, exist_ok=True, parents=True)
-            # EJO KeyError is caught in this loop since we are iterating on
-            #     all the catalogs and a failure in one catalog shouldn't stop
-            #     the show.
-            if title:
-                try:
-                    catalog.download_title(title, dest_path, file_format, overwrite)
-                except KeyError as error:
-                    typer.secho(f"{catalog}: ", nl=False)
-                    typer.secho(str(error).strip('"'), fg="red")
-                continue
-
-            if package:
-                try:
-                    catalog.download_package(package, dest_path, file_format, overwrite)
-                except KeyError as error:
-                    typer.secho(f"{catalog}: ", nl=False)
-                    typer.secho(str(error).strip('"'), fg="red")
-                continue
-
-            catalog.download(dest, file_format, overwrite=overwrite)
-
-    except KeyError as error:
-        typer.secho(str(error), fg="red")
-        raise typer.Exit(-1) from None
-
-    except PermissionError as error:
-        typer.secho("Permission error for: ", nl=False)
-        typer.secho(str(error.filename), fg="red")
-        raise typer.Exit(-1) from None
-
-
-@cli.command("download")
-def download2_subcommand(
     ctx: typer.Context,
     component: Component,
-    name: str = typer.Option(None, "--name", "-n", help=""),
+    name: str = typer.Option(
+        None, "--name", "-n", help="Name to match against title or package."
+    ),
     dest_path: Path = typer.Option(
         Path.cwd(),
         "--dest-path",
@@ -493,6 +360,66 @@ def download2_subcommand(
         help="Over write downloaded files.",
     ),
 ):
+    """Download textbooks from Springer
+
+    This command downloads textbooks from Springer to the local host. Files
+    are saved by default in PDF format to the current working directory.
+
+    If a download is interrupted by the user, it can be later restarted where
+    the interruption occurred without downloading previous files. 
+
+    Problems encountered while downloading files are logged to:
+
+    `dest-path/DOWNLOAD_REPORT.txt`
+
+    __Examples__
+
+    Download all books in the default catalog in PDF format to the
+    current directory:
+
+    `$ springer download books`
+
+    Download all books in EPUB format whose title includes 'python':
+
+    `$ springer download books --name python --file-format epub`
+
+    Download all books into directories grouped by package:
+
+    `$ springer download packages --dest-path by_pkgs
+
+    Download all books in a specific package in EPUB format:
+
+    `$ springer download package --name 'Computer Science' --file-format epub`
+
+    Download all books in packages whose name includes `Science`:
+
+    `$ springer download package --name science --dest sciences`
+
+    Download all books in all catalogs [en-all, de-all, de-med] in EPUB format:
+
+    `$ springer download catalogs --file-format epub`
+
+    The `catalogs` download subcommand will create a set of directories by language
+    and topic for each catalog and save downloaded files into the appropriate
+    directory, eg:
+
+    \b
+    dest-path/English/All_Disciplines/package_name/title.fmt
+    dest-path/German/All_Disciplines/package_name/title.fmt
+    dest-path/German/Emergency_Nursing/package_name/title.fmt
+
+    The `package` and `packages` subcommands will also save downloaded
+    files into directories with package names rooted in the destination
+    path:
+
+    \b
+    dest-path/package_name/title.fmt
+    ...
+
+
+
+    See Also: `set-default-catalog`, `get-default-catalog`, `list`
+    """
 
     dest_path = dest_path.resolve()
 
@@ -519,7 +446,7 @@ def download2_subcommand(
                 package_names = ctx.obj.packages.keys()
 
             for pkgname in package_names:
-                path = dest_path / pkgname.casefold().replace(" ", "_")
+                path = dest_path / pkgname.replace(" ", "_")
                 path.mkdir(mode=0o755, exist_ok=True, parents=True)
                 ctx.obj.download_package(pkgname, path, file_format, overwrite)
             return
@@ -527,14 +454,12 @@ def download2_subcommand(
         if component is Component.Catalogs:
 
             for catalog in Catalog.all_catalogs():
-
-                path = dest_path / catalog.language / catalog.topic
+                path = dest_path / catalog.language.name / catalog.topic.name
                 path.mkdir(mode=0o755, exist_ok=True, parents=True)
-                try:
-                    catalog.download(path, file_format, overwrite)
-                except KeyError as error:
-                    typer.secho(str(error), fg="red")
-                    continue
+                for pkgname in catalog.packages:
+                    path = dest_path / pkgname.replace(" ", "_")
+                    path.mkdir(mode=0o755, exist_ok=True, parents=True)
+                    catalog.download_package(pkgname, path, file_format, overwrite)
 
     except KeyError as error:
         typer.secho(str(error), fg="red")
